@@ -12,6 +12,7 @@ from .fan import Fan
 from .light import Light
 from .notification import Notification
 from .numeric_value import NumericValue
+from .raw_value import RawValue
 from .scene import Scene
 from .sensor import Sensor
 from .switch import Switch
@@ -31,6 +32,7 @@ __all__ = [
     "Light",
     "Notification",
     "NumericValue",
+    "RawValue",
     "Scene",
     "Sensor",
     "Switch",
