@@ -46,6 +46,7 @@ class ClimateMode(Device):
         group_address_controller_mode_state: GroupAddressesType | None = None,
         group_address_heat_cool: GroupAddressesType | None = None,
         group_address_heat_cool_state: GroupAddressesType | None = None,
+        sync_state: bool | int | float | str = True,
         operation_modes: list[str | HVACOperationMode] | None = None,
         controller_modes: list[str | HVACControllerMode] | None = None,
         device_updated_cb: DeviceCallbackType | None = None,
@@ -57,7 +58,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_operation_mode,
             group_address_state=group_address_operation_mode_state,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Operation mode",
             climate_mode_type=RemoteValueOperationMode.ClimateModeType.HVAC_MODE,
@@ -67,7 +68,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_controller_mode,
             group_address_state=group_address_controller_mode_state,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Controller mode",
             after_update_cb=None,
@@ -76,7 +77,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_controller_status,
             group_address_state=group_address_controller_status_state,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Controller status",
             climate_mode_type=RemoteValueOperationMode.ClimateModeType.CONTROLLER_STATUS,
@@ -87,7 +88,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_operation_mode_comfort,
             group_address_state=group_address_operation_mode_comfort,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Operation mode Comfort",
             operation_mode=HVACOperationMode.COMFORT,
@@ -97,7 +98,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_operation_mode_standby,
             group_address_state=group_address_operation_mode_standby,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Operation mode Standby",
             operation_mode=HVACOperationMode.STANDBY,
@@ -107,7 +108,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_operation_mode_night,
             group_address_state=group_address_operation_mode_night,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Operation mode Night",
             operation_mode=HVACOperationMode.NIGHT,
@@ -117,7 +118,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_operation_mode_protection,
             group_address_state=group_address_operation_mode_protection,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Operation mode Protection",
             operation_mode=HVACOperationMode.FROST_PROTECTION,
@@ -127,7 +128,7 @@ class ClimateMode(Device):
             xknx,
             group_address=group_address_heat_cool,
             group_address_state=group_address_heat_cool_state,
-            sync_state=True,
+            sync_state=sync_state,
             device_name=name,
             feature_name="Heat/Cool",
             controller_mode=HVACControllerMode.HEAT,
