@@ -3,25 +3,26 @@ from __future__ import annotations
 
 from xknx.exceptions import ConversionError
 
-from .dpt import DPTBase
+from .dpt import DPTNumeric
 
 
-class DPTScaling(DPTBase):
+class DPTScaling(DPTNumeric):
     """
     Abstraction for KNX 1 Octet Percent.
 
     DPT 5.001
     """
 
-    value_min = 0
-    value_max = 100
-    resolution = 100 / 255
     dpt_main_number = 5
     dpt_sub_number = 1
     value_type = "percent"
     unit = "%"
     payload_length = 1
 
+    value_min = 0
+    value_max = 100
+    resolution = 1
+
     @classmethod
     def from_knx(cls, raw: tuple[int, ...]) -> int:
         """Parse/deserialize from KNX/IP raw data."""
@@ -65,10 +66,11 @@ class DPTAngle(DPTScaling):
     DPT 5.003
     """
 
-    value_min = 0
-    value_max = 360
-    resolution = 360 / 255
     dpt_main_number = 5
     dpt_sub_number = 3
     value_type = "angle"
     unit = "°"
+
+    value_min = 0
+    value_max = 360
+    resolution = 1
